@@ -6,7 +6,7 @@
 //! [`TorClient::connect`].
 
 #[cfg(feature = "rpc")]
-mod rpc;
+use {derive_deftly::Deftly, tor_rpcbase::templates::*};
 
 use crate::address::{IntoTorAddr, ResolveInstructions, StreamInstructions};
 
@@ -70,6 +70,7 @@ use tracing::{debug, info};
 // implicit Arcs inside them! maybe it's time to replace much of the insides of
 // this with an Arc<TorClientInner>?
 #[derive(Clone)]
+#[cfg_attr(feature = "rpc", derive(Deftly), derive_deftly(Object))]
 pub struct TorClient<R: Runtime> {
     /// Asynchronous runtime object.
     runtime: R,
@@ -1239,6 +1240,20 @@ impl<R: Runtime> TorClient<R> {
         &self.chanmgr
     }
 
+    /// Return a reference to this client's circuit pool.
+    ///
+    /// This function is unstable. It is only enabled if the crate was
+    /// built with the `experimental-api` feature and any of `onion-service-client`
+    /// or `onion-service-service` features. This method is required to invoke
+    /// tor_hsservice::OnionService::launch()
+    #[cfg(all(
+        feature = "experimental-api",
+        any(feature = "onion-service-client", feature = "onion-service-service")
+    ))]
+    pub fn hs_circ_pool(&self) -> &Arc<tor_circmgr::hspool::HsCircPool<R>> {
+        &self.hs_circ_pool
+    }
+
     /// Return a reference to the runtime being used by this client.
     //
     // This API is not a hostage to fortune since we already require that R: Clone,
