@@ -36,6 +36,7 @@
 #![deny(clippy::ref_option_ref)]
 #![warn(clippy::semicolon_if_nothing_returned)]
 #![warn(clippy::trait_duplication_in_bounds)]
+#![deny(clippy::unchecked_duration_subtraction)]
 #![deny(clippy::unnecessary_wraps)]
 #![warn(clippy::unseparated_literal_suffix)]
 #![deny(clippy::unwrap_used)]
@@ -209,7 +210,7 @@ impl MistrustBuilder {
     /// By default, we trust the group (if any) with the same name as the
     /// current user if we are currently running as a member of that group.
     ///
-    /// With this option set, no group is trusted, and and any group-readable or
+    /// With this option set, no group is trusted, and any group-readable or
     /// group-writable objects are treated the same as world-readable and
     /// world-writable objects respectively.
     #[cfg(all(
@@ -595,6 +596,7 @@ mod test {
     #![allow(clippy::bool_assert_comparison)]
     #![allow(clippy::clone_on_copy)]
     #![allow(clippy::dbg_macro)]
+    #![allow(clippy::mixed_attributes_style)]
     #![allow(clippy::print_stderr)]
     #![allow(clippy::print_stdout)]
     #![allow(clippy::single_char_pattern)]
