@@ -30,6 +30,7 @@
 #![deny(clippy::ref_option_ref)]
 #![warn(clippy::semicolon_if_nothing_returned)]
 #![warn(clippy::trait_duplication_in_bounds)]
+#![deny(clippy::unchecked_duration_subtraction)]
 #![deny(clippy::unnecessary_wraps)]
 #![warn(clippy::unseparated_literal_suffix)]
 #![deny(clippy::unwrap_used)]
@@ -44,6 +45,7 @@ use std::collections::BinaryHeap;
 use std::fmt;
 use std::mem;
 use std::ops::{RangeInclusive, RangeToInclusive};
+use std::path::Path;
 use std::time::Duration;
 
 pub mod iter;
@@ -275,6 +277,30 @@ impl<T: Ord> BinaryHeapExt<T> for BinaryHeap<T> {
 
 // ----------------------------------------------------------------------
 
+/// Renaming of `Path::display` as `display_lossy`
+pub trait PathExt: Sealed {
+    /// Display this `Path` as an approximate string, for human consumption in messages
+    ///
+    /// Operating system paths cannot always be faithfully represented as Rust strings,
+    /// because they might not be valid Unicode.
+    ///
+    /// This helper method provides a way to display a string for human users.
+    /// **This may lose information** so should only be used for error messages etc.
+    ///
+    /// This method is exactly the same as [`std::path::Path::display`],
+    /// but with a different and more discouraging name.
+    fn display_lossy(&self) -> std::path::Display<'_>;
+}
+impl Sealed for Path {}
+impl PathExt for Path {
+    #[allow(clippy::disallowed_methods)]
+    fn display_lossy(&self) -> std::path::Display<'_> {
+        self.display()
+    }
+}
+
+// ----------------------------------------------------------------------
+
 /// Define an "accessor trait", which describes structs that have fields of certain types
 ///
 /// This can be useful if a large struct, living high up in the dependency graph,
@@ -563,6 +589,7 @@ mod test {
     #![allow(clippy::bool_assert_comparison)]
     #![allow(clippy::clone_on_copy)]
     #![allow(clippy::dbg_macro)]
+    #![allow(clippy::mixed_attributes_style)]
     #![allow(clippy::print_stderr)]
     #![allow(clippy::print_stdout)]
     #![allow(clippy::single_char_pattern)]
