@@ -194,7 +194,19 @@ impl<R: Runtime> CircMgr<R> {
         guardmgr.set_filter(config.path_rules().build_guard_filter());
 
         #[cfg(all(feature = "vanguards", feature = "hs-common"))]
-        let vanguardmgr = VanguardMgr::new(config.vanguard_config(), storage.clone())?;
+        let vanguardmgr = {
+            // TODO(#1382): we need a way of checking if this arti instance
+            // is running an onion service or not.
+            //
+            // Perhaps this information should be provided by CircMgrConfig.
+            let has_onion_svc = false;
+            VanguardMgr::new(
+                config.vanguard_config(),
+                runtime.clone(),
+                storage.clone(),
+                has_onion_svc,
+            )?
+        };
 
         let storage_handle = storage.create_handle(PARETO_TIMEOUT_DATA_KEY);
 
@@ -279,6 +291,15 @@ impl<R: Runtime> CircMgr<R> {
             .guardmgr()
             .install_netdir_provider(&dir_provider.clone().upcast_arc())?;
 
+        #[cfg(all(feature = "vanguards", feature = "hs-common"))]
+        {
+            let () = self
+                .mgr
+                .peek_builder()
+                .vanguardmgr()
+                .launch_background_tasks(&dir_provider.clone().upcast_arc())?;
+        }
+
         Ok(ret)
     }
 
@@ -899,8 +920,8 @@ mod test {
     use super::*;
 
     /// Helper type used to help type inference.
-    pub(crate) type OptDummyGuardMgr<'a> =
-        Option<&'a tor_guardmgr::GuardMgr<tor_rtcompat::tokio::TokioNativeTlsRuntime>>;
+    pub(crate) type OptDummyGuardMgr<'a, R = tor_rtcompat::tokio::TokioNativeTlsRuntime> =
+        Option<&'a tor_guardmgr::GuardMgr<R>>;
 
     #[test]
     fn get_params() {
