@@ -391,6 +391,12 @@ pub enum ErrorKind {
     #[display(fmt = "problem with network or connection")]
     LocalNetworkError,
 
+    /// More of a local resource was needed, than is available (or than we are allowed)
+    ///
+    /// For example, we tried to use more memory than permitted by our memory quota.
+    #[display(fmt = "local resource exhausted")]
+    LocalResourceExhausted,
+
     /// A problem occurred when launching or communicating with an external
     /// process running on this computer.
     #[display(fmt = "an externally launched plug-in tool failed")]
