@@ -1,6 +1,9 @@
 #!/usr/bin/env python3
 #
 # List our crates as they appear in Cargo.toml.  Useful for scripting.
+#
+# NB you may want list_crates_publish instead
+# *This* script excludes crates according to an ad-hoc criterion
 
 import toml.decoder
 import sys
@@ -19,7 +22,7 @@ def strip_prefix(s, prefixes):
 
 def crate_list():
     t = toml.decoder.load(WORKSPACE_TOML)
-    return list(strip_prefix(name, ["crates/", "examples/gsoc2023/", "examples/hyper/"]) for name in t['workspace']['members'])
+    return list(strip_prefix(name, ["crates/", "maint/", "examples/gsoc2023/", "examples/hyper/"]) for name in t['workspace']['members'])
 
 
 if __name__ == '__main__':
